==> mstatus-applet_0.1.tar.gz: mstatus-applet-0.1/src/mstatus.h <==
#ifndef __MSTATUS_STATUS_MENU_ITEM_H__
#define __MSTATUS_STATUS_MENU_ITEM_H__

#include <libhildondesktop/libhildondesktop.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <libxml/xpathInternals.h>

G_BEGIN_DECLS
#define MSTATUS_TYPE_STATUS_MENU_ITEM            (mstatus_status_menu_item_get_type ())
#define MSTATUS_STATUS_MENU_ITEM(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), MSTATUS_TYPE_STATUS_MENU_ITEM, MStatusStatusMenuItem))
#define MSTATUS_STATUS_MENU_ITEM_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  MSTATUS_TYPE_STATUS_MENU_ITEM, MStatusStatusMenuItemClass))
#define MSTATUS_IS_STATUS_MENU_ITEM(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MSTATUS_TYPE_STATUS_MENU_ITEM))
#define MSTATUS_IS_STATUS_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  MSTATUS_TYPE_STATUS_MENU_ITEM))
#define MSTATUS_STATUS_MENU_ITEM_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  MSTATUS_TYPE_STATUS_MENU_ITEM, MStatusStatusMenuItemClass))
typedef struct _MStatusStatusMenuItem MStatusStatusMenuItem;

typedef struct _MStatusStatusMenuItemClass
 MStatusStatusMenuItemClass;

typedef struct _MStatusStatusMenuItemPrivate
 MStatusStatusMenuItemPrivate;

struct _MStatusStatusMenuItem {
	HDStatusMenuItem parent;

	MStatusStatusMenuItemPrivate *priv;
};

struct _MStatusStatusMenuItemClass {
	HDStatusMenuItemClass parent;
};

GType mstatus_status_menu_item_get_type (void);

/**/
#define	CONF_DIR		"/home/user/.mstatus/"
#define CONF_FILE		CONF_DIR"mstatus.conf"
#define MSTATUS_ICON		"/usr/share/pixmaps/mstatus.png"
#define XML_FILE		"/tmp/ret.xml"
#define API_KEY			"yourAPIkey"
#define URL_BASE		"http://api.ping.fm/v1/"
#define GTK_RESPONSE_REFRESH 	3
#define GTK_RESPONSE_PROPERTIES	4
		


gboolean verify ( gchar *method, gchar *key );
gchar * get_last_status( gchar *method, gchar *key );
gboolean post ( gchar *method, gchar *key, gchar *post_method, gchar *body );
gchar *  execute_xpath_expression(const char* filename, const xmlChar* xpathExpr, const xmlChar* nsList, char *t);
int  register_namespaces(xmlXPathContextPtr xpathCtx, const xmlChar* nsList);
gchar * print_xpath_nodes(xmlNodeSetPtr nodes, char *m);
void get ( gchar *url , gchar *user_key, gchar *limit, gchar *post_method, gchar *body );

/**/

G_END_DECLS
#endif

==> mstatus-applet_0.5.tar.gz: mstatus-applet-0.5/src/mstatus.h <==
#ifndef __MSTATUS_STATUS_MENU_ITEM_H__
#define __MSTATUS_STATUS_MENU_ITEM_H__

#include <libhildondesktop/libhildondesktop.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <libxml/xpathInternals.h>

G_BEGIN_DECLS
#define MSTATUS_TYPE_STATUS_MENU_ITEM            (mstatus_status_menu_item_get_type ())
#define MSTATUS_STATUS_MENU_ITEM(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), MSTATUS_TYPE_STATUS_MENU_ITEM, MStatusStatusMenuItem))
#define MSTATUS_STATUS_MENU_ITEM_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  MSTATUS_TYPE_STATUS_MENU_ITEM, MStatusStatusMenuItemClass))
#define MSTATUS_IS_STATUS_MENU_ITEM(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MSTATUS_TYPE_STATUS_MENU_ITEM))
#define MSTATUS_IS_STATUS_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  MSTATUS_TYPE_STATUS_MENU_ITEM))
#define MSTATUS_STATUS_MENU_ITEM_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  MSTATUS_TYPE_STATUS_MENU_ITEM, MStatusStatusMenuItemClass))
typedef struct _MStatusStatusMenuItem MStatusStatusMenuItem;

typedef struct _MStatusStatusMenuItemClass
 MStatusStatusMenuItemClass;

typedef struct _MStatusStatusMenuItemPrivate
 MStatusStatusMenuItemPrivate;

struct _MStatusStatusMenuItem {
	HDStatusMenuItem parent;

	MStatusStatusMenuItemPrivate *priv;
};

struct _MStatusStatusMenuItemClass {
	HDStatusMenuItemClass parent;
};

GType mstatus_status_menu_item_get_type (void);

/**/
#define	CONF_DIR		"/home/user/.mstatus/"
#define CONF_FILE		CONF_DIR"mstatus.conf"
#define MSTATUS_ICON		"/usr/share/pixmaps/mstatus.png"
#define XML_FILE		"/tmp/ret.xml"
#define API_KEY			"e428a9d7caf533cbedb8676a2089e949"
#define URL_BASE		"http://api.ping.fm/v1/"
#define GTK_RESPONSE_REFRESH 	3
#define GTK_RESPONSE_PROPERTIES	4
		


gboolean verify ( gchar *method, gchar *key );
gchar * get_last_status( gchar *method, gchar *key );
gboolean post ( gchar *method, gchar *key, gchar *post_method, gchar *body );
gchar *  execute_xpath_expression(const char* filename, const xmlChar* xpathExpr, const xmlChar* nsList, char *t);
int  register_namespaces(xmlXPathContextPtr xpathCtx, const xmlChar* nsList);
gchar * print_xpath_nodes(xmlNodeSetPtr nodes, char *m);
void get ( gchar *url , gchar *user_key, gchar *limit, gchar *post_method, gchar *body );

/**/

G_END_DECLS
#endif
